CloudPosTransactionStatus enum

Status values for a Cloud POS staged transaction.

Maps to the backend CloudPosTransactionStatus enum.

Inheritance
Available extensions

Values

staged → const CloudPosTransactionStatus

Transaction has been staged but not yet sent to the terminal.

pushed → const CloudPosTransactionStatus

Transaction has been pushed to the terminal but not yet acknowledged.

pendingOnTerminal → const CloudPosTransactionStatus

Transaction has been pushed to the terminal and is awaiting processing.

cardPresented → const CloudPosTransactionStatus

The cardholder has presented their card to the terminal.

approved → const CloudPosTransactionStatus

The transaction was approved by the acquirer.

declined → const CloudPosTransactionStatus

The transaction was declined by the acquirer.

timedOut → const CloudPosTransactionStatus

The terminal did not respond within the expected timeout.

error → const CloudPosTransactionStatus

The transaction failed due to a terminal or network error.

abandoned → const CloudPosTransactionStatus

The transaction was abandoned by the merchant/operator.

completed → const CloudPosTransactionStatus

The transaction completed successfully (terminal state).

failed → const CloudPosTransactionStatus

The transaction failed due to a processing failure on the backend.

terminalBusy → const CloudPosTransactionStatus

The target terminal is already processing another CloudPOS transaction. No transaction was staged.

Properties

finaliseStatus CloudPosTransactionStatus?

Available on CloudPosTransactionStatus, provided by the CloudPosTransactionStatusExtension extension

Maps this client-side status to the status that should be sent to the backend /finalise endpoint to unlock the target terminal.
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isTerminal bool

Available on CloudPosTransactionStatus, provided by the CloudPosTransactionStatusExtension extension

Whether this status represents a terminal (completed) state.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toApiString() String

Available on CloudPosTransactionStatus, provided by the CloudPosTransactionStatusExtension extension

Returns the API string representation of this status.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CloudPosTransactionStatus>
A constant List of the values in this enum, in order of their declaration.