primaryActionDisabled property
When true, the primary action button is disabled (e.g. no more items).
Implementation
final bool primaryActionDisabled;
When true, the primary action button is disabled (e.g. no more items).
final bool primaryActionDisabled;