showRetry property
When true, a full-width retry button is displayed instead of the refresh + primary-action row.
Implementation
final bool showRetry;
When true, a full-width retry button is displayed instead of the refresh + primary-action row.
final bool showRetry;