ButtonPrimary class

A primary action button themed via LittleFishThemingService.

This is the CloudPos clone of the merchant-app ButtonPrimary. All colour lookups that previously used AppliedButton / AppliedTextIcon theme extensions are replaced with ThemeSettings.colorPalette tokens, and AppVariables.appDefaultElevation / appDefaultRadius are replaced with ThemeSettings.buttonStyles.

Inheritance

Constructors

ButtonPrimary({Key? key, dynamic onTap(BuildContext context)?, required String text, Color? textColor, Color? buttonColor, double radius = -1, double elevation = -1, IconData? icon, bool disabled = false, bool upperCase = false, bool widgetOnBrandedSurface = false, bool expand = true, bool layoutVertically = false, bool isNegative = false, bool isNeutral = false, IconData? leftIcon, IconData? rightIcon, PrimaryButtonTextSize? buttonTextSize = PrimaryButtonTextSize.small, bool? isBold = true, bool? animate = true})
const

Properties

animate bool?
final
buttonColor Color?
final
buttonTextSize PrimaryButtonTextSize?
final
disabled bool
final
elevation double
final
expand bool
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
final
isBold bool?
final
isNegative bool
final
isNeutral bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
layoutVertically bool
final
leftIcon IconData?
final
onTap → dynamic Function(BuildContext context)?
final
radius double
final
rightIcon IconData?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
textColor Color?
final
upperCase bool
final
widgetOnBrandedSurface bool
widgetOnBrandedSurface = true shows onPrimary coloured button on Primary canvas widgetOnBrandedSurface = false shows primary coloured button on non primary canvas
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited