CloudPosTerminalBusyException class

Thrown by CloudPosApiClient.stageTransaction when the backend rejects the request because the target terminal is already processing a CloudPOS transaction (HTTP 409 Conflict). No transaction was staged.

Implemented types

Constructors

CloudPosTerminalBusyException(String targetTerminalId)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetTerminalId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited